Welcome to PySelenScrapr documentation!
===================================

**PySelenScrapr** is a Python package that allows you to scrape data from websites using Selenium. It is a wrapper around the Selenium package that makes it safer and easier to scrape data from websites.

The main features of PySelenScrapr are:
    - **Safe**: Each step has a retry and validate mechanism that makes the scraping process safer.
    - **Easy**: The package is easy to use and has a simplified API.
    - **Retry Mechanism**: The package has a retry mechanism that allows you to retry a step if it fails.
    - **Validate Mechanism**: The package has a validate mechanism that allows you to validate the result of a step.
    - **Data Binding**: The package has a data binding mechanism that allows you to bind the result to a webhook or other services
    - **Screenshot Mechanism**: The package has a screenshot mechanism that allows you to take a screenshot of the page at any step.
    - **Error Handling**: The package has an error handling mechanism that allows you to handle errors in a more efficient way and send it your backend
    - **Docker Support**: In combination with this docker package you can run the script scheduled with user interface: https://github.com/donnercody/python-selenium-scraper-template

Check out the :doc:`usage` section for further information, including
how to :ref:`installation` the project.

.. note::

   This project is under active development.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage

.. toctree::
    :maxdepth: 4
    :caption: API Reference

    pyselenscrapr




